Welcome to the VFM IRP


This package contains the code for the Imperial College ACSE-9 Individual Research Project of Nicolas Trinephi. It contains tools to create data frames from well data and machine learning to predict oil, gas and water rates from that data.

Contents:
```
VFM_IRP_ACSE9-1.0/  
├── LICENSE.txt  
├── README.txt  
├── setup.py  
└── VFM_Code/  
    ├──	__init__.py  
    ├──	model.py  
    ├──	pandas_data.py  
    ├──	q_control.py  
    ├──	spark_data.py  
    ├──	utils.py  
    ├──	VFM_Main.ipynb  
    └──	visualization.py  
``` 


If you are concerned about Unicode characters you can use ASCII to build the structures, so your example structure becomes

.
+-- _config.yml
+-- _drafts
|   +-- begin-with-the-crazy-ideas.textile
|   +-- on-simplicity-in-technology.markdown
+-- _includes
|   +-- footer.html
|   +-- header.html
+-- _layouts
|   +-- default.html
|   +-- post.html
+-- _posts
|   +-- 2007-10-29-why-every-programmer-should-play-nethack.textile